var hierarchy =
[
    [ "BaseClass", null, [
      [ "ImplementsImpl< BaseClass, Directly< I, DirectIFs... >, Indirectly< IndirectIFs... > >", "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html", null ]
    ] ],
    [ "ConstStringTable", "classSteinberg_1_1ConstStringTable.html", null ],
    [ "Destroyer", "structSteinberg_1_1FUnknownImpl_1_1Destroyer.html", null ],
    [ "Directly< T >", "structSteinberg_1_1FUnknownImpl_1_1Directly.html", null ],
    [ "FReleaser", "structSteinberg_1_1FReleaser.html", null ],
    [ "FUID", "classSteinberg_1_1FUID.html", null ],
    [ "FUnknown", "classSteinberg_1_1FUnknown.html", [
      [ "HideIIDBase", "structSteinberg_1_1FUnknownImpl_1_1HideIIDBase.html", null ],
      [ "IAttributes", "classSteinberg_1_1IAttributes.html", [
        [ "IAttributes2", "classSteinberg_1_1IAttributes2.html", null ]
      ] ],
      [ "IBStream", "classSteinberg_1_1IBStream.html", null ],
      [ "ICloneable", "classSteinberg_1_1ICloneable.html", null ],
      [ "IDependent", "classSteinberg_1_1IDependent.html", null ],
      [ "IErrorContext", "classSteinberg_1_1IErrorContext.html", null ],
      [ "IPersistent", "classSteinberg_1_1IPersistent.html", null ],
      [ "IPlugFrame", "classSteinberg_1_1IPlugFrame.html", null ],
      [ "IPlugView", "classSteinberg_1_1IPlugView.html", null ],
      [ "IPlugViewContentScaleSupport", "classSteinberg_1_1IPlugViewContentScaleSupport.html", null ],
      [ "IPluginBase", "classSteinberg_1_1IPluginBase.html", null ],
      [ "IPluginCompatibility", "classSteinberg_1_1IPluginCompatibility.html", null ],
      [ "IPluginFactory", "classSteinberg_1_1IPluginFactory.html", [
        [ "IPluginFactory2", "classSteinberg_1_1IPluginFactory2.html", [
          [ "IPluginFactory3", "classSteinberg_1_1IPluginFactory3.html", null ]
        ] ]
      ] ],
      [ "ISizeableStream", "classSteinberg_1_1ISizeableStream.html", null ],
      [ "IString", "classSteinberg_1_1IString.html", null ],
      [ "IStringResult", "classSteinberg_1_1IStringResult.html", null ],
      [ "IUpdateHandler", "classSteinberg_1_1IUpdateHandler.html", null ],
      [ "IEventHandler", "classSteinberg_1_1Linux_1_1IEventHandler.html", null ],
      [ "IRunLoop", "classSteinberg_1_1Linux_1_1IRunLoop.html", null ],
      [ "ITimerHandler", "classSteinberg_1_1Linux_1_1ITimerHandler.html", null ]
    ] ],
    [ "FVariant", "classSteinberg_1_1FVariant.html", null ],
    [ "I", null, [
      [ "ImplementsImpl< BaseClass, Directly< I, DirectIFs... >, Indirectly< IndirectIFs... > >", "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html", null ]
    ] ],
    [ "ImplementsImpl< Base, D, I >", "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl.html", null ],
    [ "ImplementsImpl< Base, Indirectly< IndirectInterfaces... >, Directly< DirectInterfaces... > >", "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01Base_00_01Indirectly_3_01IndirectInterfaces9a4a5325b3bc049eba78ef3421c75dc0.html", null ],
    [ "Indirectly< T >", "structSteinberg_1_1FUnknownImpl_1_1Indirectly.html", null ],
    [ "IPtr< I >", "classSteinberg_1_1IPtr.html", [
      [ "FUnknownPtr< I >", "classSteinberg_1_1FUnknownPtr.html", null ],
      [ "OPtr< I >", "classSteinberg_1_1OPtr.html", null ]
    ] ],
    [ "KeyCode", "structSteinberg_1_1KeyCode.html", null ],
    [ "NonDestroyable", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1NonDestroyable.html", null ],
    [ "PClassInfo", "structSteinberg_1_1PClassInfo.html", null ],
    [ "PClassInfo2", "structSteinberg_1_1PClassInfo2.html", null ],
    [ "PClassInfoW", "structSteinberg_1_1PClassInfoW.html", null ],
    [ "PFactoryInfo", "structSteinberg_1_1PFactoryInfo.html", null ],
    [ "RefCounted", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1RefCounted.html", null ],
    [ "T", null, [
      [ "QueryInterfaceEnd< T >", "structSteinberg_1_1FUnknownImpl_1_1Detail_1_1QueryInterfaceEnd.html", null ]
    ] ],
    [ "UID< t1, t2, t3, t4 >", "structSteinberg_1_1FUnknownImpl_1_1UID.html", null ],
    [ "UString", "classSteinberg_1_1UString.html", [
      [ "UStringBuffer< maxSize >", "classSteinberg_1_1UStringBuffer.html", null ]
    ] ],
    [ "ViewRect", "structSteinberg_1_1ViewRect.html", null ],
    [ "DirectIFs", null, [
      [ "ImplementsImpl< BaseClass, Directly< I, DirectIFs... >, Indirectly< IndirectIFs... > >", "classSteinberg_1_1FUnknownImpl_1_1ImplementsImpl_3_01BaseClass_00_01Directly_3_01I_00_01DirectIFb25833aad28d70bbd485c48835745987.html", null ]
    ] ]
];